# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Workspace(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "workspace_name": "WorkspaceName",
        "workspace_id": "int",
        "workspace_created_at": "datetime",
        "workspace_require_2fa": "bool",
        "workspace_enable_sdn_connections": "bool",
    }

    attribute_map = {
        "workspace_name": "workspace_name",
        "workspace_id": "workspace_id",
        "workspace_created_at": "workspace_created_at",
        "workspace_require_2fa": "workspace_require_2fa",
        "workspace_enable_sdn_connections": "workspace_enable_sdn_connections",
    }

    def __init__(
        self,
        workspace_name=None,
        workspace_id=None,
        workspace_created_at=None,
        workspace_require_2fa=None,
        workspace_enable_sdn_connections=None,
    ):  # noqa: E501
        """Workspace - a model defined in Swagger"""  # noqa: E501
        self._workspace_name = None
        self._workspace_id = None
        self._workspace_created_at = None
        self._workspace_require_2fa = None
        self._workspace_enable_sdn_connections = None
        self.discriminator = None
        self.workspace_name = workspace_name
        self.workspace_id = workspace_id
        self.workspace_created_at = workspace_created_at
        self.workspace_require_2fa = workspace_require_2fa
        self.workspace_enable_sdn_connections = workspace_enable_sdn_connections

    @property
    def workspace_name(self):
        """Gets the workspace_name of this Workspace.  # noqa: E501


        :return: The workspace_name of this Workspace.  # noqa: E501
        :rtype: WorkspaceName
        """
        return self._workspace_name

    @workspace_name.setter
    def workspace_name(self, workspace_name):
        """Sets the workspace_name of this Workspace.


        :param workspace_name: The workspace_name of this Workspace.  # noqa: E501
        :type: WorkspaceName
        """
        if workspace_name is None:
            raise ValueError(
                "Invalid value for `workspace_name`, must not be `None`"
            )  # noqa: E501

        self._workspace_name = workspace_name

    @property
    def workspace_id(self):
        """Gets the workspace_id of this Workspace.  # noqa: E501


        :return: The workspace_id of this Workspace.  # noqa: E501
        :rtype: int
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this Workspace.


        :param workspace_id: The workspace_id of this Workspace.  # noqa: E501
        :type: int
        """
        if workspace_id is None:
            raise ValueError(
                "Invalid value for `workspace_id`, must not be `None`"
            )  # noqa: E501

        self._workspace_id = workspace_id

    @property
    def workspace_created_at(self):
        """Gets the workspace_created_at of this Workspace.  # noqa: E501


        :return: The workspace_created_at of this Workspace.  # noqa: E501
        :rtype: datetime
        """
        return self._workspace_created_at

    @workspace_created_at.setter
    def workspace_created_at(self, workspace_created_at):
        """Sets the workspace_created_at of this Workspace.


        :param workspace_created_at: The workspace_created_at of this Workspace.  # noqa: E501
        :type: datetime
        """
        if workspace_created_at is None:
            raise ValueError(
                "Invalid value for `workspace_created_at`, must not be `None`"
            )  # noqa: E501

        self._workspace_created_at = workspace_created_at

    @property
    def workspace_require_2fa(self):
        """Gets the workspace_require_2fa of this Workspace.  # noqa: E501


        :return: The workspace_require_2fa of this Workspace.  # noqa: E501
        :rtype: bool
        """
        return self._workspace_require_2fa

    @workspace_require_2fa.setter
    def workspace_require_2fa(self, workspace_require_2fa):
        """Sets the workspace_require_2fa of this Workspace.


        :param workspace_require_2fa: The workspace_require_2fa of this Workspace.  # noqa: E501
        :type: bool
        """
        if workspace_require_2fa is None:
            raise ValueError(
                "Invalid value for `workspace_require_2fa`, must not be `None`"
            )  # noqa: E501

        self._workspace_require_2fa = workspace_require_2fa

    @property
    def workspace_enable_sdn_connections(self):
        """Gets the workspace_enable_sdn_connections of this Workspace.  # noqa: E501


        :return: The workspace_enable_sdn_connections of this Workspace.  # noqa: E501
        :rtype: bool
        """
        return self._workspace_enable_sdn_connections

    @workspace_enable_sdn_connections.setter
    def workspace_enable_sdn_connections(self, workspace_enable_sdn_connections):
        """Sets the workspace_enable_sdn_connections of this Workspace.


        :param workspace_enable_sdn_connections: The workspace_enable_sdn_connections of this Workspace.  # noqa: E501
        :type: bool
        """
        if workspace_enable_sdn_connections is None:
            raise ValueError(
                "Invalid value for `workspace_enable_sdn_connections`, must not be `None`"
            )  # noqa: E501

        self._workspace_enable_sdn_connections = workspace_enable_sdn_connections

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(Workspace, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Workspace):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
