# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class V1AuthAccessTokenLoginItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "access_token": "str",
        "token_type": "str",
        "expires_in": "str",
        "refresh_token": "str",
    }

    attribute_map = {
        "access_token": "access_token",
        "token_type": "token_type",
        "expires_in": "expires_in",
        "refresh_token": "refresh_token",
    }

    def __init__(
        self, access_token=None, token_type=None, expires_in=None, refresh_token=None
    ):  # noqa: E501
        """V1AuthAccessTokenLoginItem - a model defined in Swagger"""  # noqa: E501
        self._access_token = None
        self._token_type = None
        self._expires_in = None
        self._refresh_token = None
        self.discriminator = None
        self.access_token = access_token
        self.token_type = token_type
        self.expires_in = expires_in
        self.refresh_token = refresh_token

    @property
    def access_token(self):
        """Gets the access_token of this V1AuthAccessTokenLoginItem.  # noqa: E501


        :return: The access_token of this V1AuthAccessTokenLoginItem.  # noqa: E501
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this V1AuthAccessTokenLoginItem.


        :param access_token: The access_token of this V1AuthAccessTokenLoginItem.  # noqa: E501
        :type: str
        """
        if access_token is None:
            raise ValueError(
                "Invalid value for `access_token`, must not be `None`"
            )  # noqa: E501

        self._access_token = access_token

    @property
    def token_type(self):
        """Gets the token_type of this V1AuthAccessTokenLoginItem.  # noqa: E501


        :return: The token_type of this V1AuthAccessTokenLoginItem.  # noqa: E501
        :rtype: str
        """
        return self._token_type

    @token_type.setter
    def token_type(self, token_type):
        """Sets the token_type of this V1AuthAccessTokenLoginItem.


        :param token_type: The token_type of this V1AuthAccessTokenLoginItem.  # noqa: E501
        :type: str
        """
        if token_type is None:
            raise ValueError(
                "Invalid value for `token_type`, must not be `None`"
            )  # noqa: E501

        self._token_type = token_type

    @property
    def expires_in(self):
        """Gets the expires_in of this V1AuthAccessTokenLoginItem.  # noqa: E501


        :return: The expires_in of this V1AuthAccessTokenLoginItem.  # noqa: E501
        :rtype: str
        """
        return self._expires_in

    @expires_in.setter
    def expires_in(self, expires_in):
        """Sets the expires_in of this V1AuthAccessTokenLoginItem.


        :param expires_in: The expires_in of this V1AuthAccessTokenLoginItem.  # noqa: E501
        :type: str
        """
        if expires_in is None:
            raise ValueError(
                "Invalid value for `expires_in`, must not be `None`"
            )  # noqa: E501

        self._expires_in = expires_in

    @property
    def refresh_token(self):
        """Gets the refresh_token of this V1AuthAccessTokenLoginItem.  # noqa: E501


        :return: The refresh_token of this V1AuthAccessTokenLoginItem.  # noqa: E501
        :rtype: str
        """
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, refresh_token):
        """Sets the refresh_token of this V1AuthAccessTokenLoginItem.


        :param refresh_token: The refresh_token of this V1AuthAccessTokenLoginItem.  # noqa: E501
        :type: str
        """
        if refresh_token is None:
            raise ValueError(
                "Invalid value for `refresh_token`, must not be `None`"
            )  # noqa: E501

        self._refresh_token = refresh_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(V1AuthAccessTokenLoginItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1AuthAccessTokenLoginItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
