# coding: utf-8

"""
    Syntropy network API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@syntropynet.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class V1AgentService(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "agent_service_name": "str",
        "agent_service_type": "AgentServiceTypes",
        "agent_service_networks": "list[str]",
        "agent_service_tcp_ports": "list[int]",
        "agent_service_udp_ports": "list[int]",
        "agent_service_is_active": "bool",
        "agent_service_created_at": "datetime",
        "agent_service_subnets": "list[AgentServiceSubnetIdAndIp]",
    }

    attribute_map = {
        "agent_service_name": "agent_service_name",
        "agent_service_type": "agent_service_type",
        "agent_service_networks": "agent_service_networks",
        "agent_service_tcp_ports": "agent_service_tcp_ports",
        "agent_service_udp_ports": "agent_service_udp_ports",
        "agent_service_is_active": "agent_service_is_active",
        "agent_service_created_at": "agent_service_created_at",
        "agent_service_subnets": "agent_service_subnets",
    }

    def __init__(
        self,
        agent_service_name=None,
        agent_service_type=None,
        agent_service_networks=None,
        agent_service_tcp_ports=None,
        agent_service_udp_ports=None,
        agent_service_is_active=None,
        agent_service_created_at=None,
        agent_service_subnets=None,
    ):  # noqa: E501
        """V1AgentService - a model defined in Swagger"""  # noqa: E501
        self._agent_service_name = None
        self._agent_service_type = None
        self._agent_service_networks = None
        self._agent_service_tcp_ports = None
        self._agent_service_udp_ports = None
        self._agent_service_is_active = None
        self._agent_service_created_at = None
        self._agent_service_subnets = None
        self.discriminator = None
        self.agent_service_name = agent_service_name
        self.agent_service_type = agent_service_type
        self.agent_service_networks = agent_service_networks
        self.agent_service_tcp_ports = agent_service_tcp_ports
        self.agent_service_udp_ports = agent_service_udp_ports
        self.agent_service_is_active = agent_service_is_active
        self.agent_service_created_at = agent_service_created_at
        self.agent_service_subnets = agent_service_subnets

    @property
    def agent_service_name(self):
        """Gets the agent_service_name of this V1AgentService.  # noqa: E501


        :return: The agent_service_name of this V1AgentService.  # noqa: E501
        :rtype: str
        """
        return self._agent_service_name

    @agent_service_name.setter
    def agent_service_name(self, agent_service_name):
        """Sets the agent_service_name of this V1AgentService.


        :param agent_service_name: The agent_service_name of this V1AgentService.  # noqa: E501
        :type: str
        """
        if agent_service_name is None:
            raise ValueError(
                "Invalid value for `agent_service_name`, must not be `None`"
            )  # noqa: E501

        self._agent_service_name = agent_service_name

    @property
    def agent_service_type(self):
        """Gets the agent_service_type of this V1AgentService.  # noqa: E501


        :return: The agent_service_type of this V1AgentService.  # noqa: E501
        :rtype: AgentServiceTypes
        """
        return self._agent_service_type

    @agent_service_type.setter
    def agent_service_type(self, agent_service_type):
        """Sets the agent_service_type of this V1AgentService.


        :param agent_service_type: The agent_service_type of this V1AgentService.  # noqa: E501
        :type: AgentServiceTypes
        """
        if agent_service_type is None:
            raise ValueError(
                "Invalid value for `agent_service_type`, must not be `None`"
            )  # noqa: E501

        self._agent_service_type = agent_service_type

    @property
    def agent_service_networks(self):
        """Gets the agent_service_networks of this V1AgentService.  # noqa: E501


        :return: The agent_service_networks of this V1AgentService.  # noqa: E501
        :rtype: list[str]
        """
        return self._agent_service_networks

    @agent_service_networks.setter
    def agent_service_networks(self, agent_service_networks):
        """Sets the agent_service_networks of this V1AgentService.


        :param agent_service_networks: The agent_service_networks of this V1AgentService.  # noqa: E501
        :type: list[str]
        """
        if agent_service_networks is None:
            raise ValueError(
                "Invalid value for `agent_service_networks`, must not be `None`"
            )  # noqa: E501

        self._agent_service_networks = agent_service_networks

    @property
    def agent_service_tcp_ports(self):
        """Gets the agent_service_tcp_ports of this V1AgentService.  # noqa: E501


        :return: The agent_service_tcp_ports of this V1AgentService.  # noqa: E501
        :rtype: list[int]
        """
        return self._agent_service_tcp_ports

    @agent_service_tcp_ports.setter
    def agent_service_tcp_ports(self, agent_service_tcp_ports):
        """Sets the agent_service_tcp_ports of this V1AgentService.


        :param agent_service_tcp_ports: The agent_service_tcp_ports of this V1AgentService.  # noqa: E501
        :type: list[int]
        """
        if agent_service_tcp_ports is None:
            raise ValueError(
                "Invalid value for `agent_service_tcp_ports`, must not be `None`"
            )  # noqa: E501

        self._agent_service_tcp_ports = agent_service_tcp_ports

    @property
    def agent_service_udp_ports(self):
        """Gets the agent_service_udp_ports of this V1AgentService.  # noqa: E501


        :return: The agent_service_udp_ports of this V1AgentService.  # noqa: E501
        :rtype: list[int]
        """
        return self._agent_service_udp_ports

    @agent_service_udp_ports.setter
    def agent_service_udp_ports(self, agent_service_udp_ports):
        """Sets the agent_service_udp_ports of this V1AgentService.


        :param agent_service_udp_ports: The agent_service_udp_ports of this V1AgentService.  # noqa: E501
        :type: list[int]
        """
        if agent_service_udp_ports is None:
            raise ValueError(
                "Invalid value for `agent_service_udp_ports`, must not be `None`"
            )  # noqa: E501

        self._agent_service_udp_ports = agent_service_udp_ports

    @property
    def agent_service_is_active(self):
        """Gets the agent_service_is_active of this V1AgentService.  # noqa: E501


        :return: The agent_service_is_active of this V1AgentService.  # noqa: E501
        :rtype: bool
        """
        return self._agent_service_is_active

    @agent_service_is_active.setter
    def agent_service_is_active(self, agent_service_is_active):
        """Sets the agent_service_is_active of this V1AgentService.


        :param agent_service_is_active: The agent_service_is_active of this V1AgentService.  # noqa: E501
        :type: bool
        """
        if agent_service_is_active is None:
            raise ValueError(
                "Invalid value for `agent_service_is_active`, must not be `None`"
            )  # noqa: E501

        self._agent_service_is_active = agent_service_is_active

    @property
    def agent_service_created_at(self):
        """Gets the agent_service_created_at of this V1AgentService.  # noqa: E501


        :return: The agent_service_created_at of this V1AgentService.  # noqa: E501
        :rtype: datetime
        """
        return self._agent_service_created_at

    @agent_service_created_at.setter
    def agent_service_created_at(self, agent_service_created_at):
        """Sets the agent_service_created_at of this V1AgentService.


        :param agent_service_created_at: The agent_service_created_at of this V1AgentService.  # noqa: E501
        :type: datetime
        """
        if agent_service_created_at is None:
            raise ValueError(
                "Invalid value for `agent_service_created_at`, must not be `None`"
            )  # noqa: E501

        self._agent_service_created_at = agent_service_created_at

    @property
    def agent_service_subnets(self):
        """Gets the agent_service_subnets of this V1AgentService.  # noqa: E501


        :return: The agent_service_subnets of this V1AgentService.  # noqa: E501
        :rtype: list[AgentServiceSubnetIdAndIp]
        """
        return self._agent_service_subnets

    @agent_service_subnets.setter
    def agent_service_subnets(self, agent_service_subnets):
        """Sets the agent_service_subnets of this V1AgentService.


        :param agent_service_subnets: The agent_service_subnets of this V1AgentService.  # noqa: E501
        :type: list[AgentServiceSubnetIdAndIp]
        """
        if agent_service_subnets is None:
            raise ValueError(
                "Invalid value for `agent_service_subnets`, must not be `None`"
            )  # noqa: E501

        self._agent_service_subnets = agent_service_subnets

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(V1AgentService, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1AgentService):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
